"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _ExpansionPanel = _interopRequireDefault(require("@material-ui/core/ExpansionPanel"));

var _ExpansionPanelDetails = _interopRequireDefault(require("@material-ui/core/ExpansionPanelDetails"));

var _ExpansionPanelSummary = _interopRequireDefault(require("@material-ui/core/ExpansionPanelSummary"));

var _Done = _interopRequireDefault(require("@material-ui/icons/Done"));

var _Close = _interopRequireDefault(require("@material-ui/icons/Close"));

var _Assignment = _interopRequireDefault(require("@material-ui/icons/Assignment"));

var _NotInterested = _interopRequireDefault(require("@material-ui/icons/NotInterested"));

var _Typography = _interopRequireDefault(require("@material-ui/core/Typography"));

var _ExpandMore = _interopRequireDefault(require("@material-ui/icons/ExpandMore"));

var _Grid = _interopRequireDefault(require("@material-ui/core/Grid"));

var _Paper = _interopRequireDefault(require("@material-ui/core/Paper"));

var _styles = require("@material-ui/core/styles");

var _parser = _interopRequireDefault(require("./parser"));

var _utils = require("./utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj["default"] = obj; return newObj; } }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

var useStyles = (0, _styles.makeStyles)(function (theme) {
  return {
    root: {
      width: '100%'
    },
    iconRecap: {
      margin: theme.spacing(1),
      fontSize: 64,
      paddingRight: 10
    },
    iconDoneCustom: {
      color: 'green'
    },
    iconCloseCustom: {
      color: 'red'
    },
    timing: {
      flexGrow: 1,
      textAlign: 'right'
    },
    summaryStatus: {
      height: '100%',
      width: 'auto',
      backgroundColor: 'green'
    },
    heading: {
      fontSize: theme.typography.pxToRem(15),
      flexBasis: '33.33%',
      flexShrink: 0
    },
    secondaryHeading: {
      fontSize: theme.typography.pxToRem(15),
      color: theme.palette.text.secondary
    },
    paperContent: {
      alignItems: "center",
      height: 100,
      justifyContent: "center"
    },
    paperContainer: {
      paddingBottom: 25
    },
    globalContainer: {
      margin: 20
    },
    messageContainer: {
      backgroundColor: '#000000',
      color: '#FFFFFF',
      width: '100%',
      borderRadius: 5
    }
  };
});

var UnitViewer = function UnitViewer(props) {
  var classes = useStyles();

  var _useState = (0, _react.useState)([]),
      _useState2 = _slicedToArray(_useState, 2),
      jsSuite = _useState2[0],
      setJsSuite = _useState2[1];

  var _useState3 = (0, _react.useState)('pending'),
      _useState4 = _slicedToArray(_useState3, 2),
      status = _useState4[0],
      setStatus = _useState4[1];

  var _React$useState = _react["default"].useState(false),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      expanded = _React$useState2[0],
      setExpanded = _React$useState2[1];

  (0, _react.useEffect)(function () {
    if (props.xml) {
      try {
        var parsedXml = (0, _parser["default"])(props.xml);
        setJsSuite(parsedXml);
        setStatus(parsedXml[0].status);
      } catch (error) {
        setStatus('Error, invalid xml');
      }
    } else {
      setStatus('Error, please provide a junit formatted XML');
    }
  }, [props.xml]);

  var handleChange = function handleChange(panel) {
    return function (event, isExpanded) {
      if (!panel.endsWith('0')) {
        setExpanded(isExpanded ? panel : false);
      }
    };
  };

  var get_headers = function get_headers() {
    if (jsSuite.length === 0) {
      return null;
    }

    var suite_header = jsSuite[0].count;
    return _react["default"].createElement("div", {
      className: classes.root
    }, _react["default"].createElement(_Grid["default"], {
      container: true,
      spacing: 3
    }, _react["default"].createElement(_Grid["default"], {
      item: true,
      sm: 3,
      xs: 12
    }, _react["default"].createElement("div", {
      className: classes.paperContainer
    }, _react["default"].createElement(_Paper["default"], {
      className: classes.paper
    }, _react["default"].createElement(_Grid["default"], {
      container: true,
      className: classes.paperContent
    }, _react["default"].createElement(_Assignment["default"], {
      className: classes.iconRecap
    }), suite_header.tests)))), _react["default"].createElement(_Grid["default"], {
      item: true,
      sm: 3,
      xs: 12
    }, _react["default"].createElement("div", {
      className: classes.paperContainer
    }, _react["default"].createElement(_Paper["default"], {
      className: classes.paper
    }, _react["default"].createElement(_Grid["default"], {
      container: true,
      className: classes.paperContent
    }, _react["default"].createElement(_Done["default"], {
      className: [classes.iconDoneCustom, classes.iconRecap]
    }), suite_header.pass)))), _react["default"].createElement(_Grid["default"], {
      item: true,
      sm: 3,
      xs: 12
    }, _react["default"].createElement("div", {
      className: classes.paperContainer
    }, _react["default"].createElement(_Paper["default"], {
      className: classes.paper
    }, _react["default"].createElement(_Grid["default"], {
      container: true,
      className: classes.paperContent
    }, _react["default"].createElement(_Close["default"], {
      className: [classes.iconCloseCustom, classes.iconRecap]
    }), suite_header.fail + suite_header.error)))), _react["default"].createElement(_Grid["default"], {
      item: true,
      sm: 3,
      xs: 12
    }, _react["default"].createElement("div", {
      className: classes.paperContainer
    }, _react["default"].createElement(_Paper["default"], {
      className: classes.paper
    }, _react["default"].createElement(_Grid["default"], {
      container: true,
      className: classes.paperContent
    }, _react["default"].createElement(_NotInterested["default"], {
      className: classes.iconRecap
    }), suite_header.skip + suite_header.unknown))))));
  };

  var get_back_icon = function get_back_icon(status) {
    if (status === 'pass') {
      return _react["default"].createElement(_Done["default"], {
        className: classes.iconDoneCustom
      });
    } else if (status === 'error' || status === 'fail') {
      return _react["default"].createElement(_Close["default"], {
        className: classes.iconCloseCustom
      });
    } else if (status === 'skip' || status === 'unknown') {
      return _react["default"].createElement(_NotInterested["default"], null);
    }

    return null;
  };

  var get_body = function get_body() {
    if (jsSuite.length === 0) {
      return null;
    }

    var suite_tests = jsSuite[0].tests;
    var listItems = suite_tests.map(function (test) {
      return _react["default"].createElement(_ExpansionPanel["default"], {
        key: test._uuid,
        expanded: expanded === (0, _utils.get_unique_expandable_id)(test),
        onChange: handleChange((0, _utils.get_unique_expandable_id)(test))
      }, _react["default"].createElement(_ExpansionPanelSummary["default"], {
        expandIcon: _react["default"].createElement(_ExpandMore["default"], null),
        "aria-controls": test._uuid + "content",
        id: test._uuid + "header"
      }, get_back_icon(test.status), _react["default"].createElement(_Typography["default"], {
        className: classes.heading
      }, test.name), _react["default"].createElement(_Typography["default"], {
        className: classes.secondaryHeading
      }, test.status), test.time && _react["default"].createElement(_Typography["default"], {
        className: classes.timing
      }, test.time, "s")), _react["default"].createElement(_ExpansionPanelDetails["default"], null, _react["default"].createElement("div", {
        className: classes.messageContainer
      }, _react["default"].createElement(_Typography["default"], null, (0, _utils.get_decoded_uri)(test.message)))));
    });
    return _react["default"].createElement("div", null, listItems);
  };

  return _react["default"].createElement("div", {
    className: classes.globalContainer
  }, _react["default"].createElement("h2", null, "Test suite : ", status), get_headers(), get_body());
};

UnitViewer.propTypes = {
  xml: _propTypes["default"].string.isRequired
};
var _default = UnitViewer;
exports["default"] = _default;